@@ -4,17 +4,18 @@
     SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
-#include <QTest>
-#include <QSignalSpy>
-#include <QTimer>
-#include <QThread>
-#include <QRandomGenerator>
-#include <kauth.h>
-#include <kauthactionreply.h>
-#include <kauthexecutejob.h>
 #include "BackendsManager.h"
 #include "TestHelper.h"
 
+#include <kauth/actionreply.h>
+#include <kauth/executejob.h>
+
+#include <QRandomGenerator>
+#include <QSignalSpy>
+#include <QTest>
+#include <QThread>
+#include <QTimer>
+
 #include "../src/backends/dbus/DBusHelperProxy.h"
 
 Q_DECLARE_METATYPE(KAuth::Action::AuthStatus)
@@ -42,12 +43,16 @@ class HelperTest : public QObject
     Q_OBJECT
 
 public:
-    HelperTest(QObject *parent = nullptr) : QObject(parent)
-    { }
+    HelperTest(QObject *parent = nullptr)
+        : QObject(parent)
+    {
+    }
 
 private Q_SLOTS:
     void initTestCase();
-    void init() {}
+    void init()
+    {
+    }
 
     void testBasicActionExecution();
     void testExecuteJobSignals();
@@ -55,8 +60,12 @@ private Q_SLOTS:
     void testActionData();
     void testHelperFailure();
 
-    void cleanup() {}
-    void cleanupTestCase() {}
+    void cleanup()
+    {
+    }
+    void cleanupTestCase()
+    {
+    }
 
 Q_SIGNALS:
     void changeCapabilities(KAuth::AuthBackend::Capabilities capabilities);
@@ -83,7 +92,7 @@ HelperHandler::HelperHandler()
 
     m_thread = new QThread(this);
     moveToThread(m_thread);
-    connect(m_thread, SIGNAL(started()), this, SLOT(init()));
+    connect(m_thread, &QThread::started, this, &HelperHandler::init);
     m_thread->start();
 }
 
@@ -97,7 +106,7 @@ void HelperHandler::init()
     // The timer is here just to prevent the app from crashing.
     QTimer *timer = new QTimer(nullptr);
 
-    QVERIFY(m_helperProxy->initHelper(QLatin1String("org.kde.kf5auth.autotest")));
+    QVERIFY(m_helperProxy->initHelper(QLatin1String("org.kde.kf6auth.autotest")));
 
     m_helperProxy->setHelperResponder(m_helper);
 
@@ -108,31 +117,33 @@ void HelperHandler::init()
     // Make BackendsManager aware
     BackendsManager::setProxyForThread(m_thread, m_helperProxy);
 
-    emit ready();
+    Q_EMIT ready();
 }
 
 void HelperTest::initTestCase()
 {
-    connect(this, SIGNAL(changeCapabilities(KAuth::AuthBackend::Capabilities)),
-            KAuth::BackendsManager::authBackend(), SLOT(setNewCapabilities(KAuth::AuthBackend::Capabilities)));
+    connect(this,
+            SIGNAL(changeCapabilities(KAuth::AuthBackend::Capabilities)),
+            KAuth::BackendsManager::authBackend(),
+            SLOT(setNewCapabilities(KAuth::AuthBackend::Capabilities)));
 
     qRegisterMetaType<KAuth::Action::AuthStatus>();
     qRegisterMetaType<KJob *>();
 
     // Set up our HelperHandler
     m_handler = new HelperHandler;
-    QEventLoop e;
-    connect(m_handler, SIGNAL(ready()), &e, SLOT(quit()));
+    QEventLoop eventLoop;
+    connect(m_handler, &HelperHandler::ready, &eventLoop, &QEventLoop::quit);
     qDebug() << "Waiting for HelperHandler to be initialized";
-    e.exec();
+    eventLoop.exec();
 }
 
 void HelperTest::testBasicActionExecution()
 {
-    emit changeCapabilities(KAuth::AuthBackend::AuthorizeFromHelperCapability | KAuth::AuthBackend::CheckActionExistenceCapability);
+    Q_EMIT changeCapabilities(KAuth::AuthBackend::AuthorizeFromHelperCapability);
 
-    KAuth::Action action(QLatin1String("org.kde.kf5auth.autotest.standardaction"));
-    action.setHelperId(QLatin1String("org.kde.kf5auth.autotest"));
+    KAuth::Action action(QLatin1String("org.kde.kf6auth.autotest.standardaction"));
+    action.setHelperId(QLatin1String("org.kde.kf6auth.autotest"));
     QVERIFY(action.isValid());
 
     QCOMPARE(action.status(), KAuth::Action::AuthRequiredStatus);
@@ -146,18 +157,18 @@ void HelperTest::testBasicActionExecution()
 
 void HelperTest::testExecuteJobSignals()
 {
-    KAuth::Action action(QLatin1String("org.kde.kf5auth.autotest.longaction"));
-    action.setHelperId(QLatin1String("org.kde.kf5auth.autotest"));
+    KAuth::Action action(QLatin1String("org.kde.kf6auth.autotest.longaction"));
+    action.setHelperId(QLatin1String("org.kde.kf6auth.autotest"));
     QVERIFY(action.isValid());
 
     QCOMPARE(action.status(), KAuth::Action::AuthRequiredStatus);
 
     KAuth::ExecuteJob *job = action.execute();
 
-    QSignalSpy finishedSpy(job, SIGNAL(result(KJob*)));
-    QSignalSpy newDataSpy(job, SIGNAL(newData(QVariantMap)));
-    QSignalSpy percentSpy(job, SIGNAL(percent(KJob*,ulong)));
-    QSignalSpy statusChangedSpy(job, SIGNAL(statusChanged(KAuth::Action::AuthStatus)));
+    QSignalSpy finishedSpy(job, &KJob::result);
+    QSignalSpy newDataSpy(job, &KAuth::ExecuteJob::newData);
+    QSignalSpy percentSpy(job, &KJob::percentChanged);
+    QSignalSpy statusChangedSpy(job, &KAuth::ExecuteJob::statusChanged);
 
     QVERIFY(job->exec());
 
@@ -179,8 +190,8 @@ void HelperTest::testExecuteJobSignals()
 
 void HelperTest::testTwoCalls()
 {
-    KAuth::Action action(QLatin1String("org.kde.kf5auth.autotest.standardaction"));
-    action.setHelperId(QLatin1String("org.kde.kf5auth.autotest"));
+    KAuth::Action action(QLatin1String("org.kde.kf6auth.autotest.standardaction"));
+    action.setHelperId(QLatin1String("org.kde.kf6auth.autotest"));
     QVERIFY(action.isValid());
 
     QCOMPARE(action.status(), KAuth::Action::AuthRequiredStatus);
@@ -189,13 +200,12 @@ void HelperTest::testTwoCalls()
 
     job = action.execute();
     QVERIFY(job->exec());
-
 }
 
 void HelperTest::testActionData()
 {
-    KAuth::Action action(QLatin1String("org.kde.kf5auth.autotest.echoaction"));
-    action.setHelperId(QLatin1String("org.kde.kf5auth.autotest"));
+    KAuth::Action action(QLatin1String("org.kde.kf6auth.autotest.echoaction"));
+    action.setHelperId(QLatin1String("org.kde.kf6auth.autotest"));
 
     QVariantMap args;
     // Fill with random data (and test heavy structures while we're at it)
@@ -218,8 +228,8 @@ void HelperTest::testActionData()
 
 void HelperTest::testHelperFailure()
 {
-    KAuth::Action action(QLatin1String("org.kde.kf5auth.autotest.failingaction"));
-    action.setHelperId(QLatin1String("org.kde.kf5auth.autotest"));
+    KAuth::Action action(QLatin1String("org.kde.kf6auth.autotest.failingaction"));
+    action.setHelperId(QLatin1String("org.kde.kf6auth.autotest"));
     QVERIFY(action.isValid());
     QCOMPARE(action.status(), KAuth::Action::AuthRequiredStatus);
     KAuth::ExecuteJob *job = action.execute();
