@@ -29,15 +29,14 @@ class Polkit1Backend : public AuthBackend
 
 public:
     Polkit1Backend();
-    virtual ~Polkit1Backend();
+    ~Polkit1Backend() override;
     void setupAction(const QString &) override;
-    void preAuthAction(const QString &action, QWidget *parent) override;
+    void preAuthAction(const QString &action, QWindow *parent) override;
     Action::AuthStatus authorizeAction(const QString &) override;
     Action::AuthStatus actionStatus(const QString &) override;
     QByteArray callerID() const override;
     ExtraCallerIDVerificationMethod extraCallerIDVerificationMethod() const override;
     virtual bool isCallerAuthorized(const QString &action, const QByteArray &callerID, const QVariantMap &details) override;
-    bool actionExists(const QString &action) override;
     QVariantMap backendDetails(const DetailsMap &details) override;
 
 private Q_SLOTS:
